/*
 * GPIO.c
 *
 *  Created on: 16.04.2014
 *      Author: FarwickT
 */
#include "GPIO.h"
#include "bare_metall_ppi_Core0.h"
#include <stdio.h>

#define GPIO_MEM_SIZE (ADI_GPIO_CALLBACK_MEM_SIZE)
static uint8_t gpioMemory[GPIO_MEM_SIZE];
uint32_t gpioMaxCallbacks;

uint8_t PB10_Pressed;


ADI_GPIO_RESULT GPIO_init(void)
{
	uint32_t result=0;
	PB10_Pressed = 0;

	result = adi_gpio_Init((void *)&gpioMemory, (uint32_t)GPIO_MEM_SIZE,&gpioMaxCallbacks);
	chkRes("GPIO init",result);
	printf("Number of Callbacks: %d\n",gpioMaxCallbacks);

	result = adi_gpio_SetDirection(ADI_GPIO_PORT_B, ADI_GPIO_PIN_10,ADI_GPIO_DIRECTION_INPUT);
	chkRes("PushButton1 PB10 as Input",result);

	result = adi_gpio_PinInterruptAssignment(ADI_GPIO_PIN_INTERRUPT_1, ADI_GPIO_PIN_ASSIGN_BYTE_1, ADI_GPIO_PIN_ASSIGN_PBH_PINT1);
	chkRes("Interrupt assignment",result);

	result = adi_gpio_EnablePinInterruptMask(ADI_GPIO_PIN_INTERRUPT_1, ADI_GPIO_PIN_10, true);
	chkRes("interrupt masking",result);

	result = adi_gpio_SetPinIntEdgeSense(ADI_GPIO_PIN_INTERRUPT_1,ADI_GPIO_PIN_10,(ADI_GPIO_SENSE)ADI_GPIO_SENSE_RISING_EDGE);
	chkRes("Edgesensing",result);

	result = adi_gpio_RegisterCallback(ADI_GPIO_PIN_INTERRUPT_1,ADI_GPIO_PIN_10, CallBack_PushButton1, (void*)0);
	chkRes("Registering Callback function",result);

	result = adi_gpio_SetDirection(ADI_GPIO_PORT_G, ADI_GPIO_PIN_14,ADI_GPIO_DIRECTION_OUTPUT);
	chkRes("LED1 PG14 as Output",result);

	result = adi_gpio_SetDirection(ADI_GPIO_PORT_E, ADI_GPIO_PIN_1,ADI_GPIO_DIRECTION_INPUT);
	chkRes("PushButton2 PE01 as Input",result);

	//Set EPPI floating EPPI pins to defined values
	result = adi_gpio_SetDirection(ADI_GPIO_PORT_B, ADI_GPIO_PIN_15,ADI_GPIO_DIRECTION_OUTPUT);
	chkRes("set PB15 for floating EPPI",result);
	result = adi_gpio_Clear(ADI_GPIO_PORT_B,ADI_GPIO_PIN_15);

	result = adi_gpio_SetDirection(ADI_GPIO_PORT_C, ADI_GPIO_PIN_8,ADI_GPIO_DIRECTION_OUTPUT);
	chkRes("set PC08 for floating EPPI",result);
	result = adi_gpio_Clear(ADI_GPIO_PORT_C,ADI_GPIO_PIN_8);

	result = adi_gpio_SetDirection(ADI_GPIO_PORT_C, ADI_GPIO_PIN_9,ADI_GPIO_DIRECTION_OUTPUT);
	chkRes("set PC09 for floating EPPI",result);
	result = adi_gpio_Clear(ADI_GPIO_PORT_C,ADI_GPIO_PIN_9);

	result = adi_gpio_SetDirection(ADI_GPIO_PORT_C, ADI_GPIO_PIN_10,ADI_GPIO_DIRECTION_OUTPUT);
	chkRes("set PC10 for floating EPPI",result);
	result = adi_gpio_Clear(ADI_GPIO_PORT_C,ADI_GPIO_PIN_10);

	result = adi_gpio_SetDirection(ADI_GPIO_PORT_C, ADI_GPIO_PIN_11,ADI_GPIO_DIRECTION_OUTPUT);
	chkRes("set PC11 for floating EPPI",result);
	result = adi_gpio_Clear(ADI_GPIO_PORT_C,ADI_GPIO_PIN_11);

	result = adi_gpio_SetDirection(ADI_GPIO_PORT_C, ADI_GPIO_PIN_12,ADI_GPIO_DIRECTION_OUTPUT);
	chkRes("set PC12 for floating EPPI",result);
	result = adi_gpio_Clear(ADI_GPIO_PORT_C,ADI_GPIO_PIN_12);

	result = adi_gpio_SetDirection(ADI_GPIO_PORT_C, ADI_GPIO_PIN_13,ADI_GPIO_DIRECTION_OUTPUT);
	chkRes("set PC12 for floating EPPI",result);
	result = adi_gpio_Clear(ADI_GPIO_PORT_C,ADI_GPIO_PIN_13);

	result = adi_gpio_SetDirection(ADI_GPIO_PORT_C, ADI_GPIO_PIN_14,ADI_GPIO_DIRECTION_OUTPUT);
	chkRes("set PC14 for floating EPPI",result);
	result = adi_gpio_Clear(ADI_GPIO_PORT_C,ADI_GPIO_PIN_14);

	result = adi_gpio_SetDirection(ADI_GPIO_PORT_C, ADI_GPIO_PIN_15,ADI_GPIO_DIRECTION_OUTPUT);
	chkRes("set PC015 for floating EPPI",result);
	result = adi_gpio_Clear(ADI_GPIO_PORT_C,ADI_GPIO_PIN_15);

	result = adi_gpio_SetDirection(ADI_GPIO_PORT_D, ADI_GPIO_PIN_0,ADI_GPIO_DIRECTION_OUTPUT);
	chkRes("set PD00 for floating EPPI",result);
	result = adi_gpio_Clear(ADI_GPIO_PORT_D,ADI_GPIO_PIN_0);

	result = adi_gpio_SetDirection(ADI_GPIO_PORT_D, ADI_GPIO_PIN_1,ADI_GPIO_DIRECTION_OUTPUT);
	chkRes("set PD01 for floating EPPI",result);
	result = adi_gpio_Clear(ADI_GPIO_PORT_D,ADI_GPIO_PIN_1);

	return (ADI_GPIO_RESULT)result;
}

void set_buttonPushed(void)
{
	PB10_Pressed = 1;
}

void clr_buttonPushed(void)
{
	PB10_Pressed = 0;
}
uint8_t get_PB10_state(void)
{
	if(PB10_Pressed == 1)
	{
		return 1;
	}
	else
	{
		return 0;
	}
}

void CallBack_PushButton1(ADI_GPIO_PIN_INTERRUPT const ePinInt, uint32_t const Data, void* pCBParam)
{
	set_buttonPushed();
	printf("processing Callback\n");

}

#pragma section ("L1_code")
void LEDOnOff(bool on)
{
	uint32_t result=0;

	if(on == true)
	{
		result = adi_gpio_Set(ADI_GPIO_PORT_G,ADI_GPIO_PIN_14);
		//chkRes("LED1 on",result);
	}
	else
	{
		adi_gpio_Clear(ADI_GPIO_PORT_G,ADI_GPIO_PIN_14);
		//chkRes("LED1 off",result);
	}
}

void chkRes(char *Text, uint32_t result)
{
	if(result != 0)
	{
		printf("%s failed: %x\r\n", Text, result);
	}
	else
	{
		printf("%s succeeded\r\n", Text);
	}
}
